##Script (Python)
##title=Copy Facets To Objects
##parameters=id
# This module copies the facets from ObjectTypes
import string
FacetTypes = context.Data.FacetTypes.objectIds( )
#PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
PATH = context.getInstancePath()
PATH = PATH + '/Data/'
Type1 = ['float','int','long']
Type2 = ['boolean']
Type3 = ['lines','string','text','tokens','selection','multiple selection']
#Type4 = ['date']

newObject = context.restrictedTraverse( PATH + 'Objects/' + id )
inheritedObjectTypes = newObject.getProperty( 'ObjectTypes' )

for x in inheritedObjectTypes:
    ObjType = context.restrictedTraverse( PATH + 'ObjectType/' + x )
    ObjTypeProperty = ObjType.propertyIds( )
    for y in ObjTypeProperty:
        if y in FacetTypes:
           if y not in newObject.propertyIds( ):
              facetType = context.restrictedTraverse(PATH + 'FacetTypes/' + y)
              facetDataType = facetType.getProperty('datatype')
              if facetDataType in Type1:
                 defFacetValue = 0
              elif facetDataType in Type2:
                 defFacetValue = 0
              elif facetDataType in Type3:
                 defFacetValue = ''
              #elif facetDataType in Type4:
                 #defFacetType = DateTime()
              newObject.manage_addProperty( y, defFacetValue, facetDataType)

